@@ -49,8 +49,8 @@ class App:
 	# copy protobuf files over
 	# copy the cakework_server file over and modify it
 
-	def register_activity(self, activity):
-		print("Registering activity")
+	def register_task(self, activity):
+		print("Registering task")
 		activity_server = ActivityServer(activity) # Q: this gets shut down?
 		activity_server.start()
 		# start the activity server
